pub enum BpCommands {
New(NewArgs),
Add(AddArgs),
Sync {
path: Option<String>,
},
Enable {
feature_name: String,
battery_pack: Option<String>,
},
List {
filter: Option<String>,
non_interactive: bool,
},
Show {
battery_pack: String,
path: Option<String>,
non_interactive: bool,
},
Status {
path: Option<String>,
},
Validate {
path: Option<String>,
},
}Variants
New(NewArgs)
Create a new project from a battery pack template
Add(AddArgs)
Add a battery pack and sync its dependencies.
Without arguments, opens an interactive TUI for managing all battery packs. With a battery pack name, adds that specific pack (with an interactive picker for choosing crates if the pack has features or many dependencies).
Sync
Update dependencies from installed battery packs
Enable
Enable a named feature from a battery pack
Fields
List
List available battery packs on crates.io
Fields
Show
Show detailed information about a battery pack
Fields
Status
Show status of installed battery packs and version warnings
Validate
Validate that the current battery pack is well-formed