load_installed_packs

Function load_installed_packs 

pub fn load_installed_packs(project_dir: &Path) -> Result<Vec<InstalledPack>>
Load all installed battery packs with their specs and active features.

Reads [build-dependencies] from the user’s Cargo.toml, fetches each battery pack’s spec via cargo metadata, and reads active features from package.metadata.battery-pack.